@@ -1,9 +1,12 @@
 from __future__ import print_function
 
+# Relative import shortcut
+from core import Hub
+
 
 __title__ = "chanjo"
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 __author__ = "Robin Andeer"
 __license__ = "MIT"
 __copyright__ = "Copyright 2013 Robin Andeer"
-__docformat__ = "restructuredtext"
\ No newline at end of file
+__docformat__ = "restructuredtext"
